@@ -8,7 +8,6 @@ class StringField(models.Field):
 
     def __init__(self, *args, **kwargs):
         kwargs.setdefault('max_length', 500)
-        kwargs.setdefault('blank', True)
         super(StringField, self).__init__(*args, **kwargs)
 
     def get_internal_type(self):
@@ -27,12 +26,22 @@ class StringField(models.Field):
         defaults.update(kwargs)
         return super(StringField, self).formfield(**defaults)
 
-    def db_type(self, connection):
-        if connection.vendor == 'postgresql':
+    def db_type(self, connection=None):
+        if connection is None:
+            # Django < 1.2 doesn't have connection
+            from django.conf import settings
+            name = settings.DATABASE_ENGINE.split('.')[-1].split('_')[0]
+            if name == 'postgis':
+                vendor = 'postgresql'
+            else:
+                vendor = name
+        else:
+            vendor = connection.vendor
+        if vendor == 'postgresql':
             return 'character varying'
-        if connection.vendor == 'mysql':
+        if vendor == 'mysql':
             return 'VARCHAR (65528)'
-        if connection.vendor == 'oracle':
+        if vendor == 'oracle':
             return 'VARCHAR2 (4000)'
         return 'TEXT'
 
